@@ -2,7 +2,7 @@ package Backblaze::B2V2Client;
 # API client library for V2 of the API to Backblaze B2 object storage
 # Allows for creating/deleting buckets, listing files in buckets, and uploading/downloading files
 
-$Backblaze::B2V2Client::VERSION = '1.1';
+$Backblaze::B2V2Client::VERSION = '1.2';
 
 # our dependencies:
 use Cpanel::JSON::XS;
@@ -650,6 +650,7 @@ Backblaze::B2V2Client - Client library for the Backblaze B2 Cloud Storage Servic
 		'file_contents' => $file_contents
 	); 
 	# B2 file ID (fGUID) is now in $b2client->{b2_response}{fileId}
+	# Best to load $file_contents via Path::Tiny's slurp_raw() method
 
 	# download that file to /opt/majestica/tmp
 	$b2client->b2_download_file_by_name('GingerAnna','ginger_was_perfect.jpg','/opt/majestica/tmp');
@@ -696,6 +697,17 @@ Key again, so copy it immediately.
 Please store the Application Key pair in a secure way, preferably encrypted 
 when not in use by your software.
 
+# NOTE: BACKBLAZE B2 IS NOW S3-COMPATIBLE
+
+Backblaze has added an S3-compatible API, which you can read about here:
+
+	https://www.backblaze.com/b2/docs/s3_compatible_api.html
+
+They are continuing to support their native B2 API, so I will continue
+to use and support this module.  I have not tested the S3 modules with
+Backblaze, but if you already have an S3 integration, it is work checking
+out how Paws::S3 or Awes::S3 works with Backblaze.
+
 =head1 METHODS
 
 =head2 new
@@ -756,6 +768,10 @@ Example 2: Uploading when the file is loaded into a scalar:
 		'file_contents' => $file_contents
 	); 	
 
+NOTE: If you are going to use the 'file_contents' method, it's best
+to load the scalar using the 'slurp_raw' method in Path::Tiny.
+(I believe 'read_file' in File::Slurp will work, but have yet to test.)
+
 You can also pass a 'content-type' key with the MIME type for the new
 file.  The default is 'b2/auto'.
 
@@ -933,12 +949,16 @@ B2 API Docs:  https://www.backblaze.com/b2/docs/
 
 Backblaze::B2 - V1 API Client for B2
 
+Paws::S3 - If using Backblaze's S3-compatible API.
+
 =head1 AUTHOR / BUGS
 
 Eric Chernoff <eric@weaverstreet.net>
 
 Please send me a note with any bugs or suggestions.
 
+Thanks to ESTRABD for submitting a bugfix when using the 'file_contents' option in the b2_upload_file() method.
+
 =head1 LICENSE
 
 MIT License
